/*
 * Copyright (c) 2014 pci-suntektech Technologies, Inc.  All Rights Reserved.
 * pci-suntektech Technologies Proprietary and Confidential.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */
package com.suntek.mway.rcs.client.aidl.plugin;

import com.suntek.mway.rcs.client.aidl.plugin.entity.richscrn.ResultInfo;
import com.suntek.mway.rcs.client.aidl.plugin.entity.richscrn.ResultUtil;
import com.suntek.mway.rcs.client.aidl.plugin.entity.richscrn.PhoneList;
import com.suntek.mway.rcs.client.aidl.plugin.entity.richscrn.RichScrnShowing;

/**
 * <p>
 * Title: The rich screen api
 * </p>
 * <p>
 * Description: The rich screen api
 * </p>
 * <p>
 * Copyright: Copyright (c) 2014
 * </p>
 * <p>
 * Company: pci-suntek
 * </p>
 * 
 * @author zrq
 * @version 1.0
 * 
 */
interface IRichScreenApi
{

    /**
     * Gets the rich screen object.
     * 
     * @param missdn
     *            the missdn
     * @param phoneEvent
     *            the phone event
     * @return the rich screen object
     */
    ResultUtil getRichScrnObj( String missdn, String phoneEvent );

    /**
     * Download rich screen object.
     * 
     * @param missdn
     *            the missdn
     * @param phoneEvent
     *            the phone event
     * @return the result info
     */
    ResultInfo downloadRichScrnObj( String missdn, String phoneEvent );

    /**
     * Clear rich screen local cache.
     * 
     * @param phoneEvent
     *            the phone event
     * @return the result info
     */
    ResultInfo clearRichScrnLocalCache( String phoneEvent );
    /**
     * Inits the handler.
     * 
     * @param cacheSize
     *            the cache size
     * @return the result info
     */
    ResultInfo init( int cacheSize );

     /**
     * Generated by the terminal authentication token and a generation
     * sourceId token to use, and then call the interface to the unified
     * authentication service platform for authentication certification
     * 
     * @return the result info
     */
    ResultInfo richScrnCMCCSSOLogin();
    /**
     * Download home local rules.
     * 
     * @param phoneEvent
     *            the phone event
     * @return the result info
     */
    ResultInfo downloadHomeLocRules( String phoneEvent );
    /**
     * Switching network terminal case,
     * notice enhanced screen SDK interface.
     * Trigger operation is completed without
     * major network under conditions
     */
    ResultInfo richScrnChangeNetWork();
    /**
     * When come and go electric, terminals see favorite 
     * pictures resources, you can call this interface Collection
     *
      * @param sourceType
     *            Resource type: 0 for static images, one for dynamic
     *            pictures, two said the video, three unknown
     * 
     * @param cId
     *            the cId is RichScreen id
     */
    ResultInfo collectRichScrnObj (String sourceType, String cId);
    /**
     *start site rich screen apk
     *
     *@param mobile 
     *             Phone number is null, the setting for everyone ,
     *             otherwise the numbers for
     */
    void startSiteApk(in PhoneList mobile);
}
